@@ -1,5 +1,8 @@
 #! /usr/bin/env bash
 
+alias @gearth=roofai_google_earth
+alias @google_earth=roofai_google_earth
+
 alias @gmaps=roofai_google_maps
 alias @google_maps=roofai_google_maps
 
