@@ -5,10 +5,15 @@ function test_roofai_help() {
 
     local module
     for module in \
+        "@gearth" \
+        "@google_earth" \
+        "@google_earth fetch" \
+        \
         "@gmaps" \
         "@google_maps" \
         "@google_maps get_static_image" \
         "@google_maps geocode" \
+        "@google_maps predict" \
         \
         "@roboflow" \
         "@roboflow create_project" \
